Types

Enum Types 

pub enum Types {
    None,
    ApiConnectionError,
    ApiError,
    AuthenticationError,
    CardError,
    IdempotencyError,
    InvalidRequestError,
    RateLimitError,
}
All available error types from 01/08/2023

Official Stripe error types list

Variants



None

No error type.



ApiConnectionError

Failure to connect to Stripe’s API.



ApiError

API errors cover any other type of problem (e.g., a temporary problem with Stripe’s servers), and are extremely uncommon.



AuthenticationError

Failure to properly authenticate yourself in the request.



CardError

Card errors are the most common type of error you should expect to handle. They result when the user enters a card that can’t be charged for some reason.



IdempotencyError

Idempotency errors occur when an Idempotency-Key is re-used on a request that does not match the first request’s API endpoint and parameters.



InvalidRequestError

Invalid request errors arise when your request has invalid parameters.



RateLimitError

Too many requests hit the API too quickly.